@@ -35,7 +35,9 @@ from ..base import AdviserTestCase
 class TestRandomWalk(AdviserTestCase):
     """Tests related to random walk in the dependency graph."""
 
-    @given(integers(min_value=1, max_value=256),)
+    @given(
+        integers(min_value=1, max_value=256),
+    )
     def test_run(self, state_factory: Callable[[], State], state_count: int) -> None:
         """Test running the random walk method."""
         state = state_factory()
