@@ -71,7 +71,10 @@ allow_prereleases = true
     def test_cut_locked(self) -> None:
         """Test removing a locked package based on direct dependencies."""
         tf = PackageVersion(
-            name="tensorflow", version="==2.0.0", index=Source("https://pypi.org/simple"), develop=False,
+            name="tensorflow",
+            version="==2.0.0",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
 
         context = flexmock(project=Project.from_strings(self._CASE_PIPFILE_LOCKED))
@@ -82,7 +85,10 @@ allow_prereleases = true
     def test_cut_locked_dev(self) -> None:
         """Test removing a locked package based on direct dev dependencies."""
         pytest = PackageVersion(
-            name="pytest", version="==2.0.0", index=Source("https://pypi.org/simple"), develop=False,
+            name="pytest",
+            version="==2.0.0",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
 
         context = flexmock(project=Project.from_strings(self._CASE_PIPFILE_LOCKED))
@@ -93,7 +99,10 @@ allow_prereleases = true
     def test_no_cut(self) -> None:
         """Test not removing a locked package based on direct dependencies."""
         tf = PackageVersion(
-            name="tensorflow", version="==1.9.0", index=Source("https://pypi.org/simple"), develop=False,
+            name="tensorflow",
+            version="==1.9.0",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
 
         context = flexmock(project=Project.from_strings(self._CASE_PIPFILE_LOCKED))
@@ -104,7 +113,10 @@ allow_prereleases = true
     def test_no_cut_dev(self) -> None:
         """Test not removing a locked package based on dev direct dependencies."""
         pytest = PackageVersion(
-            name="pytest", version="==5.3.1", index=Source("https://pypi.org/simple"), develop=False,
+            name="pytest",
+            version="==5.3.1",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
 
         context = flexmock(project=Project.from_strings(self._CASE_PIPFILE_LOCKED))
@@ -115,7 +127,10 @@ allow_prereleases = true
     def test_noop(self) -> None:
         """Test no operation if dependencies are not locked."""
         tf = PackageVersion(
-            name="tensorflow", version="==1.9.0", index=Source("https://pypi.org/simple"), develop=False,
+            name="tensorflow",
+            version="==1.9.0",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
 
         context = flexmock(project=Project.from_strings(self._CASE_PIPFILE_NOT_LOCKED))
@@ -126,7 +141,10 @@ allow_prereleases = true
     def test_noop_dev(self) -> None:
         """Test no operation if dependencies are not locked."""
         pytest = PackageVersion(
-            name="pytest", version="==5.3.1", index=Source("https://pypi.org/simple"), develop=False,
+            name="pytest",
+            version="==5.3.1",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
 
         context = flexmock(project=Project.from_strings(self._CASE_PIPFILE_NOT_LOCKED))
