@@ -51,13 +51,19 @@ class TestVersionConstrainSieve(AdviserUnitTestCase):
         unit = VersionConstraintSieve()
         with pytest.raises(PipelineUnitConfigurationSchemaError):
             unit.update_configuration(
-                {"package_name": "tensorflow", "version_specifier": None,}
+                {
+                    "package_name": "tensorflow",
+                    "version_specifier": None,
+                }
             )
 
         unit = VersionConstraintSieve()
         with pytest.raises(PipelineUnitConfigurationSchemaError):
             unit.update_configuration(
-                {"package_name": None, "version_specifier": ">2.0",}
+                {
+                    "package_name": None,
+                    "version_specifier": ">2.0",
+                }
             )
 
     def test_default_configuration(self) -> None:
@@ -68,11 +74,17 @@ class TestVersionConstrainSieve(AdviserUnitTestCase):
     def test_run_filter(self) -> None:
         """Test filtering a package based on version specifier."""
         package_version = PackageVersion(
-            name="tensorflow", version="==2.0.0", index=Source("https://pypi.org/simple"), develop=False,
+            name="tensorflow",
+            version="==2.0.0",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
         unit = VersionConstraintSieve()
         unit.update_configuration(
-            {"package_name": "tensorflow", "version_specifier": "<2.0",}
+            {
+                "package_name": "tensorflow",
+                "version_specifier": "<2.0",
+            }
         )
         unit.pre_run()
         assert list(unit.run([package_version])) == []
@@ -80,11 +92,17 @@ class TestVersionConstrainSieve(AdviserUnitTestCase):
     def test_run_no_filter(self) -> None:
         """Test not filtering a package based on version specifier."""
         package_version = PackageVersion(
-            name="tensorboard", version="==2.1.0", index=Source("https://pypi.org/simple"), develop=False,
+            name="tensorboard",
+            version="==2.1.0",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
         unit = VersionConstraintSieve()
         unit.update_configuration(
-            {"package_name": "tensorboard", "version_specifier": ">2.0",}
+            {
+                "package_name": "tensorboard",
+                "version_specifier": ">2.0",
+            }
         )
         unit.pre_run()
         assert list(unit.run([package_version])) == [package_version]
@@ -93,7 +111,10 @@ class TestVersionConstrainSieve(AdviserUnitTestCase):
         """Make sure the pre-run method of the base is called."""
         unit = VersionConstraintSieve()
         unit.update_configuration(
-            {"package_name": "tensorflow", "version_specifier": "==2.3",}
+            {
+                "package_name": "tensorflow",
+                "version_specifier": "==2.3",
+            }
         )
 
         assert unit.unit_run is False
