@@ -27,6 +27,7 @@ from thoth.adviser.exceptions import NotAcceptable
 from thoth.python import PackageVersion
 from thoth.python import Source
 from thoth.storages import GraphDatabase
+from thoth.storages.exceptions import NotFoundError
 
 from ..base import AdviserUnitTestCase
 
@@ -78,7 +79,11 @@ class TestSecurityIndicatorStep(AdviserUnitTestCase):
     @pytest.mark.parametrize(
         "recommendation_type", [RecommendationType.LATEST, RecommendationType.PERFORMANCE, RecommendationType.TESTING]
     )
-    def test_no_include(self, builder_context: PipelineBuilderContext, recommendation_type,) -> None:
+    def test_no_include(
+        self,
+        builder_context: PipelineBuilderContext,
+        recommendation_type,
+    ) -> None:
         """Test not including this pipeline unit step."""
         builder_context.decision_type = None
         builder_context.recommendation_type = recommendation_type
@@ -92,7 +97,10 @@ class TestSecurityIndicatorStep(AdviserUnitTestCase):
         ).and_return(self._SECURITY_INFO_EXISTS).once()
 
         package_version = PackageVersion(
-            name="flask", version="==0.12.0", index=Source("https://pypi.org/simple"), develop=False,
+            name="flask",
+            version="==0.12.0",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
 
         context = flexmock(graph=GraphDatabase())
@@ -112,10 +120,13 @@ class TestSecurityIndicatorStep(AdviserUnitTestCase):
         flexmock(GraphDatabase)
         GraphDatabase.should_receive("get_si_aggregated_python_package_version").with_args(
             package_name="flask", package_version="0.12.0", index_url="https://pypi.org/simple"
-        ).and_return(None).once()
+        ).and_raise(NotFoundError).once()
 
         package_version = PackageVersion(
-            name="flask", version="==0.12.0", index=Source("https://pypi.org/simple"), develop=False,
+            name="flask",
+            version="==0.12.0",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
 
         context = flexmock(graph=GraphDatabase(), stack_info=[])
@@ -134,10 +145,13 @@ class TestSecurityIndicatorStep(AdviserUnitTestCase):
         flexmock(GraphDatabase)
         GraphDatabase.should_receive("get_si_aggregated_python_package_version").with_args(
             package_name="flask", package_version="0.12.0", index_url="https://pypi.org/simple"
-        ).and_return(None).once()
+        ).and_raise(NotFoundError).once()
 
         package_version = PackageVersion(
-            name="flask", version="==0.12.0", index=Source("https://pypi.org/simple"), develop=False,
+            name="flask",
+            version="==0.12.0",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
 
         context = flexmock(graph=GraphDatabase())
@@ -165,7 +179,10 @@ class TestSecurityIndicatorStep(AdviserUnitTestCase):
         ).and_return(self._HIGH_HIGH_SECURITY_INFO).once()
 
         package_version = PackageVersion(
-            name="flask", version="==0.12.0", index=Source("https://pypi.org/simple"), develop=False,
+            name="flask",
+            version="==0.12.0",
+            index=Source("https://pypi.org/simple"),
+            develop=False,
         )
 
         context = flexmock(graph=GraphDatabase(), stack_info=[])
