@@ -77,12 +77,14 @@ class DependencyMonkey:
             output_func = self._dm_stdout_output  # type: ignore
         elif self.stack_output.startswith(("https://", "http://")):
             _LOGGER.info(
-                "Results of Dependency Monkey run will be submitted to API endpoint %r", self.stack_output,
+                "Results of Dependency Monkey run will be submitted to API endpoint %r",
+                self.stack_output,
             )
             output_func = partial(self._dm_amun_output, self.stack_output, self.context or {})  # type: ignore
         else:
             _LOGGER.info(
-                "Results of Dependency Monkey run will be stored in directory %r", self.stack_output,
+                "Results of Dependency Monkey run will be stored in directory %r",
+                self.stack_output,
             )
             output_func = partial(self._dm_dir_output, self.stack_output)  # type: ignore
 
