@@ -45,7 +45,9 @@ class GraphDigestsFetcher(DigestsFetcherBase):  # type: ignore
     def fetch_digests(self, package_name: str, package_version: str) -> Dict[str, List[Dict[str, str]]]:
         """Fetch digests for the given package in specified version, consider only enabled indexes."""
         _LOGGER.debug(
-            "Querying graph database for digests for package %r in version %r", package_name, package_version,
+            "Querying graph database for digests for package %r in version %r",
+            package_name,
+            package_version,
         )
 
         result = {}
