@@ -157,7 +157,14 @@ class TemporalDifference(AdaptiveSimulatedAnnealing):
         self._steps_taken += 1
         self._next_state = self.context.beam.max()
         if self.keep_history:
-            self._temperature_history.append((self._temperature, True, 0.0, self.context.accepted_final_states_count,))
+            self._temperature_history.append(
+                (
+                    self._temperature,
+                    True,
+                    0.0,
+                    self.context.accepted_final_states_count,
+                )
+            )
 
         return self._next_state, self._do_exploitation(self._next_state)
 
