@@ -29,12 +29,13 @@ from typing import Generator
 from typing import TYPE_CHECKING
 
 from packaging.specifiers import Specifier
+from voluptuous import Required
+from voluptuous import Schema
 
 import attr
 from thoth.python import PackageVersion
 
 from ..sieve import Sieve
-from ..exceptions import SieveError
 
 if TYPE_CHECKING:
     from ..pipeline_builder import PipelineBuilderContext
@@ -47,6 +48,7 @@ class VersionConstraintSieve(Sieve):
     """Filter out packages based on version constraints if they occur in the stack."""
 
     CONFIGURATION_DEFAULT = {"package_name": None, "version_specifier": None}
+    CONFIGURATION_SCHEMA = Schema({Required("package_name"): str, Required("version_specifier"): str})
 
     _specifier = attr.ib(type=Optional[Specifier], default=None, init=False)
 
@@ -57,13 +59,8 @@ class VersionConstraintSieve(Sieve):
 
     def pre_run(self) -> None:
         """Parse and initialize specifier used."""
-        if self.configuration["package_name"] is None:
-            raise SieveError(f"Package name for {self.__class__.__name__!r} is not set")
-
-        if self.configuration["version_specifier"] is None:
-            raise SieveError(f"Package version specifier for {self.__class__.__name__!r} is not set")
-
         self._specifier = Specifier(self.configuration["version_specifier"])
+        super().pre_run()
 
     def run(self, package_versions: Generator[PackageVersion, None, None]) -> Generator[PackageVersion, None, None]:
         """Filter out packages based on build time/installation issues.."""
