@@ -17,21 +17,23 @@
 
 """Implementation of steps used, specific for TensorFlow."""
 
-from .tf_21_urllib3 import TensorFlow21Urllib3Step
-from .tf_22_prob import TensorFlow22ProbabilityStep
-from .tf_avx2 import TensorFlowAVX2Step
 from .tf_113_numpy import TensorFlow113NumPyStep
 from .tf_114_gast import TensorFlow114GastStep
+from .tf_21_h5py import TensorFlow21H5pyStep
+from .tf_21_urllib3 import TensorFlow21Urllib3Step
 from .tf_22_numpy import TensorFlow22NumPyStep
+from .tf_22_prob import TensorFlow22ProbabilityStep
+from .tf_avx2 import TensorFlowAVX2Step
 from .tf_rm_scipy import TensorFlowRemoveSciPyStep
 
 
 __all__ = [
-    "TensorFlow21Urllib3Step",
-    "TensorFlow22ProbabilityStep",
-    "TensorFlowAVX2Step",
     "TensorFlow113NumPyStep",
     "TensorFlow114GastStep",
+    "TensorFlow21H5pyStep",
+    "TensorFlow21Urllib3Step",
     "TensorFlow22NumPyStep",
+    "TensorFlow22ProbabilityStep",
+    "TensorFlowAVX2Step",
     "TensorFlowRemoveSciPyStep",
 ]
