@@ -64,6 +64,7 @@ class Unit(metaclass=abc.ABCMeta):
     _RE_CAMEL2SNAKE = re.compile("(?!^)([A-Z]+)")
     _AICOE_PYTHON_PACKAGE_INDEX_URL = "https://tensorflow.pypi.thoth-station.ninja/index/"
     _VALIDATE_UNIT_CONFIGURATION_SCHEMA = bool(int(os.getenv("THOTH_ADVISER_VALIDATE_UNIT_CONFIGURATION_SCHEMA", 1)))
+    _DATA_DIR = os.path.join(os.path.dirname(os.path.realpath(__file__)), "data")
 
     @classmethod
     def should_include(cls, builder_context: "PipelineBuilderContext") -> Optional[Dict[str, Any]]:
@@ -133,7 +134,9 @@ class Unit(metaclass=abc.ABCMeta):
                 self.CONFIGURATION_SCHEMA(self.configuration)
             except Exception as exc:
                 _LOGGER.exception(
-                    "Failed to validate schema for pipeline unit %r: %s", self.name, str(exc),
+                    "Failed to validate schema for pipeline unit %r: %s",
+                    self.name,
+                    str(exc),
                 )
                 raise PipelineUnitConfigurationSchemaError(str(exc))
 
@@ -183,7 +186,8 @@ class Unit(metaclass=abc.ABCMeta):
             }
 
         _LOGGER.warning(
-            "Failed to parse AICoE specific package source index configuration: %r", package_version.index.url,
+            "Failed to parse AICoE specific package source index configuration: %r",
+            package_version.index.url,
         )
         return None
 
